=== modified file 'hooks/hooks.py'
--- hooks/hooks.py	2015-03-13 16:05:48 +0000
+++ hooks/hooks.py	2015-04-13 15:49:49 +0000
@@ -22,6 +22,7 @@
     relations_of_type,
     relation_set,
     relation_ids,
+    relation_id,
     unit_get
 )
 from charmhelpers.contrib.charmsupport import nrpe
@@ -852,6 +853,46 @@
         yaml.safe_dump(ports, pfile)
 
 
+def get_log_files():
+    """
+    Read all of the apache config files from __ and get ErrorLog and AccessLog
+    values.
+
+    Returns a tuple with first value list of access log files and second value
+    list of error log files.
+    """
+    access_logs = []
+    error_logs = []
+    for protocol in ['http', 'https']:
+        vhost_name = '%s_%s' % (config_get()['servername'], protocol)
+        vhost_file = site_filename(vhost_name)
+        for line in open(vhost_file, 'r'):
+            if 'AccessLog' in line:
+                access_logs.append(line.split()[1])
+            elif 'ErrorLog' in line:
+                error_logs.append(line.split()[1])
+    return access_logs, error_logs
+
+
+def logs_relation_joined():
+    """
+    Sets relation value with filenames
+    """
+    access_log_files, error_log_files = get_log_files()
+    log_files = access_log_files[:]
+    log_files = access_log_files.extend(error_log_files)
+    types = ['apache_access' for a in access_log_files]
+    types.extend(['apache_error' for a in error_log_files])
+    data = {'files': '\n'.join(log_files),
+            'types': '\n'.join(types),
+            }
+    relation_set(
+        relation_id=relation_id(),
+        relation_settings=data)
+    log("logs-relation-joined setting relation data for {} to {}".foramt(
+        relation_id(), data))
+
+
 ###############################################################################
 # Main section
 ###############################################################################
@@ -889,6 +930,8 @@
         update_nrpe_checks()
     elif hook_name == "vhost-config-relation-changed":
         config_changed()
+    elif hook_name == "logs-relation-joined":
+        logs_relation_joined()
     else:
         print "Unknown hook"
         sys.exit(1)

=== added symlink 'hooks/logs-relation-joined'
=== target is 'hooks.py'
=== modified file 'metadata.yaml'
--- metadata.yaml	2014-10-29 00:10:14 +0000
+++ metadata.yaml	2015-04-13 15:49:49 +0000
@@ -18,6 +18,8 @@
     scope: container
   website:
     interface: http
+  logs:
+    interface: logs
 requires:
   reverseproxy:
     interface: http

